import org.openqa.selenium.By;
import org.openqa.selenium.NoSuchElementException;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.FluentWait;
import org.openqa.selenium.support.ui.Wait;

import java.time.Duration;

public class ShopHomePage {
    private final WebDriver driver;

    public ShopHomePage(WebDriver driver) {
        this.driver = driver;
    }

    public void goToHomePage() {
        driver.get("https://skleptest.pl");
    }

    public String getTitle() {
        return driver.getTitle();
    }

    public WebElement pressProductButton(String number) {
        WebElement button = driver.findElement(By.xpath("//a[contains(@data-product_id,"+number+")]"));
        button.click();
        Wait<WebDriver> wait = new FluentWait<>(driver)
                .withTimeout(Duration.ofSeconds(30))
                .pollingEvery(Duration.ofMillis(500))
                .ignoring(NoSuchElementException.class);
        return wait.until(driver -> button.findElement(By.xpath("//a[contains(@class,\"added_to_cart\")]")));
    }

    public void pressCartButton() {
        WebElement button = driver.findElement(By.xpath("//li[@class=\"top-cart\"]"));
        button.click();
        Wait<WebDriver> wait = new FluentWait<>(driver)
                .withTimeout(Duration.ofSeconds(30))
                .pollingEvery(Duration.ofMillis(500))
                .ignoring(NoSuchElementException.class);
        wait.until(ExpectedConditions.urlToBe("https://skleptest.pl/cart/"));
    }
}
